
% This is a graphic interface for Bayesian Linear Regression.
% Prepare your data in a EXCEL file.
% Follow instruction on screen, you can estimate the model by clicking the mouse.
% If you do not need graphic interface, you can directly call the Matlab functions 
% GIBBS_LINEAR(Y,X,ndraws,burn_in)
%  
% Version: 06/2012
% Written by Hang Qian, Iowa State University
% Contact me:  matlabist@gmail.com


clear all
H_figure1 = figure('color',[0.1,0.6,0.8]);
set(H_figure1,'position',[200 200 700 500]);

H_welcome = uicontrol(H_figure1,'style','text');
set(H_welcome,'position',[100 200 500 250]);
set(H_welcome,'string',{'Welcome to Bayesian Linear Regression';'Version 1.0';'Writen by Hang Qian';'Iowa State University';' ';...
     'Follow These Simple Steps        '; '1. Load EXCEL Data             '; '2. Specify Regressors             '; '3. Watch and Have Fun          '});
set(H_welcome,'fontsize',12);

H_start = uicontrol(H_figure1,'style','pushbutton');
set(H_start,'position',[500 50 100 60]);
set(H_start,'string','NEXT');
set(H_start,'fontsize',15);
set(H_start,'callback','set(H_figure1,''visible'',''off'');set(H_figure2,''visible'',''on'');');


H_exit = uicontrol(H_figure1,'style','pushbutton');
set(H_exit,'position',[100 50 100 60]);
set(H_exit,'string','EXIT');
set(H_exit,'fontsize',15);
set(H_exit,'callback','delete(H_figure1);return');


H_figure2 = figure('color',[0.1,0.6,0.8]);
set(H_figure2,'position',[200 200 700 500]);
set(H_figure2,'visible','off');

H_welcome = uicontrol(H_figure2,'style','text');
set(H_welcome,'position',[100 200 500 250]);
set(H_welcome,'string',{'STEP 1: Load EXCEL data';' ';'Save your data in an EXCEL file';'Each variable takes one column. First row is variable names';...
    ' ';'Example:';'GDP inc  tax';'2.1  7.8  8.2';'2.6  7.9  8.5';'2.8  8.4  8.0';'3.5  9.8  7.6';...
    '';'Please enter the EXCEL file name or select a file'});
set(H_welcome,'fontsize',12);
set(H_welcome,'HorizontalAlignment','left');

file_name = 'SampleOLSData.xls';
H_filename = uicontrol(H_figure2,'style','edit');
set(H_filename,'position',[100 140 400 40]);
set(H_filename,'backgroundcolor','white');
set(H_filename,'string',file_name);
set(H_filename,'HorizontalAlignment','Left');
set(H_filename,'fontsize',12);

H_selectfile = uicontrol(H_figure2,'style','pushbutton');
set(H_selectfile,'position',[550 140 50 40]);
set(H_selectfile,'string','...');
set(H_selectfile,'fontsize',18);
set(H_selectfile,'callback','[name,path]=uigetfile({''*.xls;*.xlsx;*.csv''});if name~=0;set(H_filename,''string'',[path,name]);end;');

H_next_step = uicontrol(H_figure2,'style','pushbutton');
set(H_next_step,'position',[500 50 100 60]);
set(H_next_step,'string','NEXT');
set(H_next_step,'fontsize',15);
set(H_next_step,'callback','file_name = get(H_filename,''string'');set(H_figure2,''visible'',''off'');set(H_figure3,''visible'',''on'');');

H_previous_step = uicontrol(H_figure2,'style','pushbutton');
set(H_previous_step,'position',[100 50 100 60]);
set(H_previous_step,'string','BACK');
set(H_previous_step,'fontsize',15);
set(H_previous_step,'callback',';set(H_figure2,''visible'',''off'');set(H_figure1,''visible'',''on'');');


H_figure3 = figure('color',[0.1,0.6,0.8]);
set(H_figure3,'position',[200 200 700 500]);
set(H_figure3,'visible','off');

H_welcome = uicontrol(H_figure3,'style','text');
set(H_welcome,'position',[100 350 500 110]);
set(H_welcome,'string',{'STEP 2. Specify your regressors';...
    'Variables names are those in your EXCEL data heading';'Lagged variable, say GDP(-1), are supported, provided that observations are arranged from earliest to latest';...
    'Flat but proper priors are specified in ''GIBBS_LINEAR.m'',you can manually change them if needed.'})
set(H_welcome,'fontsize',12);
set(H_welcome,'HorizontalAlignment','left');

H_y_text = uicontrol(H_figure3,'style','text');
set(H_y_text,'position',[100 300 200 25]);
set(H_y_text,'string','Dependent Variable (Y)');
set(H_y_text,'fontsize',12);

Y_str = [];
H_y = uicontrol(H_figure3,'style','edit');
set(H_y,'position',[350 300 100 25]);
set(H_y,'string','');
set(H_y,'fontsize',12);
set(H_y,'HorizontalAlignment','Left');
set(H_y,'backgroundcolor','white');

H_x_text = uicontrol(H_figure3,'style','text');
set(H_x_text,'position',[100 270 200 25]);
set(H_x_text,'string','Regressors (X)');
set(H_x_text,'fontsize',12);

X_str = [];
H_x = uicontrol(H_figure3,'style','edit');
set(H_x,'position',[350 270 200 25]);
set(H_x,'string','');
set(H_x,'fontsize',12);
set(H_x,'HorizontalAlignment','Left');
set(H_x,'backgroundcolor','white');

add_constant = 0;
H_constant = uicontrol(H_figure3,'style','checkbox');
set(H_constant,'position',[100 230 350 20]);
set(H_constant,'string','  Add a constant (intercept) term in X');
set(H_constant,'fontsize',11);
set(H_constant,'callback','add_constant = get(H_constant,''Value'');');


H_ndraws_text = uicontrol(H_figure3,'style','text');
set(H_ndraws_text,'position',[100 180 200 20]);
set(H_ndraws_text,'string','Number of MCMC draws');
set(H_ndraws_text,'fontsize',12);

ndraws = 50000;
H_ndraws = uicontrol(H_figure3,'style','edit');
set(H_ndraws,'position',[350 180 200 25]);
set(H_ndraws,'string',num2str(ndraws));
set(H_ndraws,'fontsize',12);
set(H_ndraws,'backgroundcolor','white');

H_burn_in_text = uicontrol(H_figure3,'style','text');
set(H_burn_in_text,'position',[100 150 200 20]);
set(H_burn_in_text,'string','Number of burn-in draws');
set(H_burn_in_text,'fontsize',12);

burn_in = 10000;
H_burn_in = uicontrol(H_figure3,'style','edit');
set(H_burn_in,'position',[350 150 200 25]);
set(H_burn_in,'string',num2str(burn_in));
set(H_burn_in,'fontsize',12);
set(H_burn_in,'backgroundcolor','white');


H_next_step = uicontrol(H_figure3,'style','pushbutton');
set(H_next_step,'position',[500 50 100 60]);
set(H_next_step,'string','DONE');
set(H_next_step,'fontsize',15);
set(H_next_step,'callback','Y_str = get(H_y,''string'');X_str = get(H_x,''string'');ndraws = str2num(get(H_ndraws,''string''));burn_in = str2num(get(H_burn_in,''string''));close(H_figure3);DATA_PROCESS;');


H_previous_step = uicontrol(H_figure3,'style','pushbutton');
set(H_previous_step,'position',[100 50 100 60]);
set(H_previous_step,'string','BACK');
set(H_previous_step,'fontsize',15);
set(H_previous_step,'callback','set(H_figure3,''visible'',''off'');set(H_figure2,''visible'',''on'')');


